function xiplus1 = PoincareMap_VanderPol(xi)

% starting with a clean slate
clc;

% initial condition
Y0 = [0; xi];

% time duration and time list
tmax = 50;
tspan = linspace(0,tmax,1000)';

% solving the ODE
options = odeset('reltol',1e-9,'abstol',1e-9,'Events',@EventVanderPol);
[tlist,Ylist] = ode45(@OdeVanderPol,tspan,Y0,options);

xiplus1 = Ylist(end,2);

% plot in phase plane
figure(1); hold on;
plot(Ylist(:,1),Ylist(:,2)); xlabel('x'); ylabel('xdot');
axis equal;

% plot x and xdot as functions of time
figure(2); hold on;
subplot(211); plot(tlist,Ylist(:,1)); xlabel('t'); ylabel('x(t)');
subplot(212); plot(tlist,Ylist(:,2)); xlabel('t'); ylabel('xdot(t)');

end

%%%%%%%%%%%%%%%%

function dY = OdeVanderPol(t,Y)
% ODEVANDERPOL ode file for van der Pol equation

mu = 0.5;
y1 = Y(1); y2 = Y(2);
dY = [y2; -mu*(y1^2-1)*y2-y1];

end

%%%%%%%%%%%%%%%%

function [value,isterminal,direction] = EventVanderPol(t,Y)

value = Y(1); % this value going to zero is event defining the Poincare map, different from the other folder
isterminal = 1; % 1 means the integration stops when the event happens
direction = -1; % -1 means the integration is halted only when the 'value' is 
% decreasing

end