% this program simulates the van der Pol equation for some time T, for a
% given initial condition

% starting with a clean slate
clc; clear all; close all;

% initial condition
Y0 = [0.5; 0.5];

% time duration and time list
tmax = 50;
tspan = linspace(0,tmax,1000)';

% solving the ODE
options = odeset('reltol',1e-9,'abstol',1e-9);
[tlist,Ylist] = ode45(@OdeVanderPol,tspan,Y0,options);

% plot in phase plane
figure(1);
plot(Ylist(:,1),Ylist(:,2)); xlabel('x'); ylabel('xdot');
axis equal;

% plot x and xdot as functions of time
figure(2);
subplot(211); plot(tlist,Ylist(:,1)); xlabel('t'); ylabel('x(t)');
subplot(212); plot(tlist,Ylist(:,2)); xlabel('t'); ylabel('xdot(t)');
